from datetime import datetime, date, time
from decimal import Decimal
import mysql.simplesql as sql

tables = ['aspectvalueset']


def insertAspectValueSet(aspectValueSet):
    remaindate = datetime.combine(date.today(), time(0, 0, 0))
    yield sql.Insert(table='aspectvalueset', values={
        'aspectschemecode': aspectValueSet.get('aspectschemecode', 0),
        'aspectvaluesetcode': aspectValueSet.get('aspectvaluesetcode', 0),
        'cquant': aspectValueSet.get('cquant', None),
        'price': aspectValueSet.get('price', None),
        'tmc_code': aspectValueSet.get('tmc_code', None),
        'measure': aspectValueSet.get('measure', None),
        'remain': aspectValueSet.get('remain', None),
        'name': aspectValueSet.get('name', None),
        'remaindate': aspectValueSet.get('remaindate', remaindate),
        'packingprice': aspectValueSet.get('packingprice', None),
        'productsectioncode': aspectValueSet.get('productsectioncode', None)
    }, onDuplicateKeyUpdate=True)


def deleteAspectValueSet(aspectValueSet):
    yield sql.Delete(table='aspectvalueset',
            whereFields=['aspectvaluesetcode'],
            whereValues=[aspectValueSet.get('aspectvaluesetcode', None)])


def clearAspectValueSet():
    yield sql.DeleteAll(table='aspectvalueset')


def deleteAspectValueSetByCode(code):
    yield sql.Delete(table='aspectvalueset', whereFields=['aspectvaluesetcode'], whereValues=[code])


def increaseAspectValueSetRemain(aspectValueSet):
    remaindate = datetime.combine(date.today(), time(0, 0, 0))
    yield sql.IncreaseOrInsertValue(table='aspectvalueset', increaseField='remain',
            increaseValue=Decimal(aspectValueSet.get('remain', 0)).quantize(Decimal('.001')),
            values={
                'aspectschemecode': aspectValueSet.get('aspectschemecode', 0),
                'cquant': aspectValueSet.get('cquant', None),
                'price': aspectValueSet.get('price', None),
                'measure': aspectValueSet.get('measure', None),
                'name': aspectValueSet.get('name', None),
                'remaindate': aspectValueSet.get('remaindate', remaindate),
                'packingprice': aspectValueSet.get('packingprice', None),
            },
            whereFields=['tmc_code', 'productsectioncode'],
            whereValues=[aspectValueSet.get('tmc_code', None), aspectValueSet.get('productsectioncode', None)])
